@@ -31,6 +31,7 @@ import sys
 from dataclasses import dataclass, field
 from typing import IO, Iterable, Optional, Tuple, cast
 
+from ..configuration import GT4SDConfiguration
 from ..training_pipelines import (
     TRAINING_PIPELINE_ARGUMENTS_MAPPING,
     TRAINING_PIPELINE_MAPPING,
@@ -44,6 +45,12 @@ SUPPORTED_TRAINING_PIPELINES = sorted(
     list(set(TRAINING_PIPELINE_ARGUMENTS_MAPPING) & set(TRAINING_PIPELINE_MAPPING))
 )
 
+# disable cudnn if issues with gpu training
+if GT4SDConfiguration.get_instance().gt4sd_disable_cudnn:
+    import torch
+
+    torch.backends.cudnn.enabled = False
+
 
 @dataclass
 class TrainerArguments:
@@ -121,7 +128,9 @@ class TrainerArgumentParser(ArgumentParser):
             if "gt4sd.cli.trainer.TrainerArguments" not in str(dataclass_type)
         ]
         try:
-            parsed_arguments = super().parse_json_file(json_file=json_file)
+            parsed_arguments = super().parse_json_file(  # type:ignore
+                json_file=json_file, allow_extra_keys=True
+            )
         except Exception:
             logger.exception(
                 f"error parsing configuration file: {json_file}, printing error and exiting"
